Module item

Module item 

Item types and related helpers.

Items represent objects the player can interact with. Some may act as containers for other items. Functions here handle display logic and movement between locations.

Structs

ConsumableOpts
Extra options / data for consumable items are represented here.
Item
Anything in ‘AmbleWorld’ that can be inspected or manipulated apart from NPCs.

Enums

ConsumeType
Types of things that can happen when an item has been consumed.
ContainerState
All of the valid states a container can be in.
IngestMode
Modes of using ingestible items.
ItemAbility
Things an item can do.
ItemInteractionType
Things you can do to an item, but only with certain other items.
ItemVisibility
Determines whether an item is listed (shows in room and item contents listings), scenery (available for some interaction but not specifically listed), or hidden (currently completely hidden from view).
Movability
Possible movability states for an Item.

Traits

ItemHolder
Methods common to things that can hold items.

Functions

consume
Consumes one use of the item with the specified ability.
interaction_requirement_met
Determine whether a tool item satisfies requirements for an interaction on a target item.